@@ -6,7 +6,7 @@ use super::hashed_password::HashedPassword;
 
 pub trait ClearTextPassword { 
     fn text(&self) -> Result<String, std::io::Error>;
-    fn hashed_password(&self) -> Result<Arc<dyn HashedPassword>, std::io::Error>;
+    fn hashed_password(&self) -> Result<Arc<dyn HashedPassword + Send + Sync>, std::io::Error>;
 }
 
 pub struct BaseClearTextPassword { 
@@ -18,7 +18,7 @@ impl ClearTextPassword for BaseClearTextPassword {
         Ok(String::from("something"))
     }
 
-    fn hashed_password(&self) -> Result<Arc<dyn HashedPassword>, std::io::Error> { 
+    fn hashed_password(&self) -> Result<Arc<dyn HashedPassword + Send + Sync>, std::io::Error> { 
         let hashed_password = BaseHashedPassword::new()?;
         Ok(Arc::new(hashed_password))
     }
